@@ -11,6 +11,7 @@ import os
 import progressbar
 import time
 import serial
+import sys
 
 from asaloader import alp
 from asaloader import device
@@ -59,7 +60,10 @@ class CommandTrnasHandler():
                 'data': (bytearray) 封包資料
             }
         """
-        start_time = time.perf_counter()
+        if sys.platform == 'win32':
+            start_time = time.perf_counter()
+        elif sys.platform == 'linux':
+            start_time = time.process_time()
         exec_time = 0
         exit_flag = False
         pac_decode_err_flag = False
@@ -77,7 +81,11 @@ class CommandTrnasHandler():
             elif self._pd.isError():
                 pac_decode_err_flag = True
                 exit_flag = True
-            exec_time = time.perf_counter() - start_time
+            
+            if sys.platform == 'win32':
+                exec_time = time.perf_counter() - start_time
+            elif sys.platform == 'linux':
+                exec_time = time.process_time() - start_time
 
         if exec_time > self.timeout:
             # timeout error
